summaryrefslogtreecommitdiff
path: root/package/qa/storages/Test10.java
diff options
context:
space:
mode:
Diffstat (limited to 'package/qa/storages/Test10.java')
-rw-r--r--package/qa/storages/Test10.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/package/qa/storages/Test10.java b/package/qa/storages/Test10.java
index 50e6ef4a7b74..6b4a5bb4113e 100644
--- a/package/qa/storages/Test10.java
+++ b/package/qa/storages/Test10.java
@@ -113,7 +113,7 @@ public class Test10 implements StorageTest {
// check cloning at current state
// the new storage still was not commited so the clone must be empty
XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xStorageFactory, xTempStorage, "SubStorage1" );
if ( xClonedSubStorage == null )
@@ -134,7 +134,7 @@ public class Test10 implements StorageTest {
if ( xClonedNameAccess.hasElements() )
{
- m_aTestHelper.Error( "The new substorage still was not commited so it must be empty!" );
+ m_aTestHelper.Error( "The new substorage still was not committed so it must be empty!" );
return false;
}
@@ -199,7 +199,7 @@ public class Test10 implements StorageTest {
if ( xCloneOfRootNA.hasElements() )
{
- m_aTestHelper.Error( "The root storage still was not commited so it's clone must be empty!" );
+ m_aTestHelper.Error( "The root storage still was not committed so it's clone must be empty!" );
return false;
}
@@ -113,7 +113,7 @@ public class Test10 implements StorageTest {
// check cloning at current state
- // the new storage still was not commited so the clone must be empty
+ // the new storage still was not committed so the clone must be empty
XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xStorageFactory, xTempStorage, "SubStorage1" );
if ( xClonedSubStorage == null )